#
# install Eisoo AnyBackup 3.5 client.
#

APP_PATH=$PWD
PLATFORM=`uname`
APP_IP=0.0.0.0			# console ip

. installcmn.sh

echo "################################################################"
echo "#                                                              #"
echo "#     Welcome to Install Eisoo AnyBackup 3.5 Client            #"
echo "#                                                              #"
echo "################################################################"

if test "$PLATFORM" = "AIX"
then 	
	cp -rf /opt/freeware/lib/libintl.a $APP_PATH
fi

#
# Check and set the Oracle environment for oracle backup and restore 
#
cfgOracleEnv ()
{
	ORAHM=`echo $ORACLE_HOME`
	if test "$ORAHM" != ""
	then
		ORAPH=`echo $PATH`
		if test "$ORAPH" != ""
		then
			ORAHMSTR="export ORACLE_HOME=$ORAHM"
			ORAPHSTR="export PATH=$ORAPH"
			sed -e "s/{ORA_ENV}/`echo ${ORAHMSTR//\//\\\/}`/g"			\
					-e "s/{ORA_PATH}/`echo ${ORAPHSTR//\//\\\/}`/g"				\
					/etc/init.d/AnyBackupClientEngine > /etc/init.d/AnyBackupClientEngine.tmp	
		fi
	else
		sed -e "s/{ORA_ENV}/''/g"			\
				-e "s/{ORA_PATH}/''/g"				\
				/etc/init.d/AnyBackupClientEngine > /etc/init.d/AnyBackupClientEngine.tmp
	fi

	mv -f /etc/init.d/AnyBackupClientEngine.tmp /etc/init.d/AnyBackupClientEngine
}

#
# create the link for oracle backup and restore
# $1: the path of AnyBackup client
createOraclelink ()
{
	ORAHM=`echo $ORACLE_HOME`
	if test "$ORAHM" != ""
	then
	    forceCreateSoftLink $ORAHM/lib/libclntsh.so $1/libclntsh.so
		if test "$PLATFORM" = "AIX"
		then 			
			forceCreateSoftLink $1/libobk.a $ORAHM/lib/libobk.a 
		else
			forceCreateSoftLink $1/libobk.so $ORAHM/lib/libobk.so 
		fi
	fi
}

installClientService ()
{
	mv -f $APP_PATH/AnyBackupClientEngine /etc/init.d/
	if (test ! "$?" = "0") then
		echo "Failed to add client service, please make sure you are running under root.'"
		exit 1
	fi

	ln -s $APP_PATH /usr/local/AnyBackupClientEngine
 
	cfgOracleEnv
	chmod 755 /etc/init.d/AnyBackupClientEngine
	chkconfig AnyBackupClientEngine --add
	
	chmod 755 sharebakconf.sh
	
	chmod -R 777 7z/*
}

#
# If AnyBackup Client has been installed, should uninstall firstly.
#
detectClientInstalled ()
{
	if test -e /usr/local/AnyBackupClientEngine
	then 
		echo ""
		echo "The current system has installed AnyBackup Client. "
		echo "Please run ./uninstall.sh to uninstall AnyBackup Client firstly."
		echo ""
		exit 1
	fi	
}

#
# check current system is ok for installing client. 
#
detectSystemEnv ()
{
	checkScriptExist service
	
	checkCommandExist sed
	checkCommandExist service
	
	if test "$PLATFORM" != "AIX"
	then
		checkCommandExist chkconfig
	fi
	
	echo "Check environment: OK"
}

getparamname ()
{
	echo $1 | awk -F "=" '{print $1}'
}

getparamvalue ()
{
	echo $1 | awk -F "=" '{print $2}'
}

#
# parse parameters
#
parseparam ()
{
	for cparam in $@
	do
		pname=`getparamname $cparam`
		case "$pname" in
			"consoleIp")
				APP_IP=`getparamvalue $cparam`
				;;
			*)
				NEED_HELP=1
				echo "Unknown parameter $cparam"
				break
				;;
			esac
	done
}

echo ""

detectSystemEnv
detectClientInstalled
detectRootPermission
parseparam $@

#
# Set address of AnyBackup Management Console
#
ip=`echo $1 | sed 's/consoleIp=//'`
if test "$ip" != ""; then
	mv $APP_PATH/svraddr.config $APP_PATH/svraddr.config.bak
	sed -e "s/127.0.0.1/$APP_IP/g" $APP_PATH/svraddr.config.bak > $APP_PATH/svraddr.config
else
	echo "Check parameters: Error"
	echo ""
	echo "Usage eg: ./install.sh consoleIp=192.168.1.156"
	echo ""
	exit 1
fi

rm svraddr.config.bak

export LD_LIBRARY_PATH=$PWD:$LD_LIBRARY_PATH
export MOZILLA_FIVE_HOME=$PWD

forceCreateSoftLink $APP_PATH/libACE.so $APP_PATH/libACE-5.6.so
forceCreateSoftLink $APP_PATH/updateclient/libACE.so $APP_PATH/updateclient/libACE-5.6.so
cp $APP_PATH/libglib-2.0.so.0.1200.3 $APP_PATH/updateclient
forceCreateSoftLink $APP_PATH/updateclient/libglib-2.0.so.0.1200.3 $APP_PATH/updateclient/libglib-2.0.so.0


if test "$PLATFORM" != "AIX"
then
	#
	# install glib standalone on AIX
	#
	forceCreateSoftLink $APP_PATH/libglib-2.0.so.0.1200.3 $APP_PATH/libglib-2.0.so
	forceCreateSoftLink $APP_PATH/libglib-2.0.so.0.1200.3 $APP_PATH/libglib-2.0.so.0
fi

createOraclelink	$APP_PATH

echo "Register XPCOM components..."
$APP_PATH/regxpcom

#
# AIX does not support service yet.
#
if test "$PLATFORM" != "AIX"
then
	echo "Install AnyBackup Client service..."
	installClientService
	echo "AnyBackup Client service has been installed successfully."
	
	echo "Start AnyBackup Client service..."
	service AnyBackupClientEngine start
fi
	
if (test ! "$?" = "0") then
	echo "Unable to start AnyBackup Client service."
	echo "Please run 'start.sh' to restart the AnyBackup Client service again."		
else
	echo "AnyBackup Client service has been started successfully."
	echo "To stop AnyBackup Client service, please try ./stop.sh."
fi
	
echo ""
