#
# Public shell script for Eisoo AnyBackup installing.
#

#
# Create a soft link, if targeted link exist, delete old targeted link firstly.
#
forceCreateSoftLink () 
{
	if test -e $2
	then 
		rm -f $2
	fi

	ln -s $1 $2
}

#
# The current user must be root if would like to install.
#
detectRootPermission ()
{
	userName=$whoami
	if (test ! "$userName"="root") then
		echo "Check root permission: Error"
		echo "You should run as root user to install AnyBackup Client."
		echo ""
		exit 1
	else
		echo "Check root permission: OK"
	fi
}

#
# Find path in $PATH envorinment variable
# 
#  $1: The path to find 
#  @return: 1 if path is in $PATH, otherwise return 0
#
findPath ()
{
	RESULT=`echo $PATH | grep -c $1`
	if test "$RESULT" = "0"
	then
		return 0
	else
		return 1
	fi
}

findColonPath ()
{
	RESULT=`echo $PATH | grep -c $1:`
	if test "$RESULT" = "0"
	then
		RESULT=`echo $PATH | grep -c :$1`
		if test "$RESULT" = "0"
		then
			return 0
		else
			return 1
		fi
	else
		return 1
	fi
}

#
# Check a command exists and can run, if does not exist, output error and abort.
#
# $1: command name(cannot contain path, i.e: service)
#
checkCommandExist ()
{
	#   /bin
   #   /sbin 
	#   /usr/bin
	#   /usr/sbin
   #   /usr/local/bin

	findColonPath /bin
	BIN_IN_PATH=$?

	findColonPath /sbin
	SBIN_IN_PATH=$?

	findPath /usr/bin
	USR_BIN_IN_PATH=$?

	findPath /usr/sbin
	USR_SBIN_IN_PATH=$?

	findPath /usr/local/bin
	USR_LOCAL_BIN_IN_PATH=$?

	if test "$SBIN_IN_PATH"="0" -a "USR_SBIN_IN_PATH"="0"
	then
		findPath /sbin
		SBIN_IN_PATH=$?
	fi

	if test "$BIN_IN_PATH"="1"
	then
		if test -x /bin/$1
		then
			return
		fi
	fi

	if test "$SBIN_IN_PATH"="1"
	then
		if test -x /sbin/$1
		then
			return
		fi
	fi

	if test "$USR_BIN_IN_PATH"="1"
	then
		if test -x /usr/bin/$1
		then
			return
		fi
	fi


	if test "$USR_SBIN_IN_PATH"="1"
	then
		if test -x /usr/sbin/$1
		then
			return
		fi
	fi

	if test "$USR_LOCAL_BIN_IN_PATH"="1"
	then
		if test -x /usr/local/bin/$1
		then
			return
		fi
	fi

	echo "Check Command: Error"
	echo "Command '$1' cannot find or cannot execute, please configure your system firstly."
	echo ""
	exit 1	
}

checkScriptExist ()
{
	if test ! -x /sbin/$1
	then
		cp $1 /sbin
		chmod -R 777 /sbin/$1
	fi
	
}
